<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.webtoffee.com
 * @since             1.0.0
 * @package           Webtoffee_Product_Feed_Sync
 *
 * @wordpress-plugin
 * Plugin Name:       Product Catalog Sync for WooCommerce
 * Plugin URI:        https://wordpress.org/plugins/webtoffee-product-feed
 * Description:       Sync your WooCommerce Products to Facebook Catalogs.
 * Version:           1.2.1
 * Author:            WebToffee
 * Author URI:        https://www.webtoffee.com
 * License:           GPL-3.0+
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain:       webtoffee-product-feed
 * Domain Path:       /languages
 * WC tested up to:   6.7
 */
// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WEBTOFFEE_PRODUCT_FEED_SYNC_VERSION', '1.2.1' );
define( 'WEBTOFFEE_PRODUCT_FEED_ID', 'webtoffee_product_feed' );
define( 'WT_PRODUCT_FEED_PLUGIN_URL', plugin_dir_url(__FILE__));
define( 'WT_PRODUCT_FEED_PLUGIN_FILENAME', __FILE__);
if (!defined('WT_PRODUCT_FEED_BASE_NAME')) {
    define('WT_PRODUCT_FEED_BASE_NAME', plugin_basename(__FILE__));
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-webtoffee-product-feed-sync-activator.php
 */
function activate_webtoffee_product_feed() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-webtoffee-product-feed-sync-activator.php';
	Webtoffee_Product_Feed_Sync_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-webtoffee-product-feed-sync-deactivator.php
 */
function deactivate_webtoffee_product_feed() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-webtoffee-product-feed-sync-deactivator.php';
	Webtoffee_Product_Feed_Sync_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_webtoffee_product_feed' );
register_deactivation_hook( __FILE__, 'deactivate_webtoffee_product_feed' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-webtoffee-product-feed-sync.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-wt-productfeed-uninstall-feedback.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_webtoffee_product_feed() {

	$plugin = new Webtoffee_Product_Feed_Sync();
	$plugin->run();
}

run_webtoffee_product_feed();
